@@ -119,7 +119,7 @@ class Container(Gtk.Overlay):
         self.add(paned)
         # Show donation notification
         if App().settings.get_value("show-donation"):
-            GLib.timeout_add_seconds(randint(10, 1000),
+            GLib.timeout_add_seconds(randint(3600, 7200),
                                      self.__show_donation)
 
     def add_webview(self, uri, loading_type, ephemeral=False,
@@ -512,7 +512,7 @@ class Container(Gtk.Overlay):
         from eolie.app_notification import AppNotification
         notification = AppNotification(
             _("Please consider a donation to the project"),
-            [_("Paypal"), _("Liberapay")],
+            [_("PayPal"), _("Liberapay")],
             [lambda: Gtk.show_uri_on_window(
                 App().active_window,
                 "https://www.paypal.me/lollypopgnome",
