@@ -1,4 +1,4 @@
-# Copyright (c) 2017 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2017-2018 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -10,20 +10,22 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import Gtk, GLib, Gio, WebKit2, Pango
+from gi.repository import Gtk, GLib, WebKit2, Pango
 
 from urllib.parse import urlparse
 from gettext import gettext as _
 
-from eolie.define import El
+from eolie.define import App
 from eolie.popover_downloads import DownloadsPopover
 from eolie.helper_passwords import PasswordsHelper
+from eolie.logger import Logger
 
 
 class ProgressBar(Gtk.ProgressBar):
     """
         Simple progress bar with width contraint
     """
+
     def __init__(self):
         Gtk.ProgressBar.__init__(self)
         self.set_property("valign", Gtk.Align.END)
@@ -62,53 +64,17 @@ class ToolbarEnd(Gtk.Bin):
         if fullscreen:
             builder.get_object("fullscreen_button").show()
         self.__progress = ProgressBar()
-        if El().download_manager.get():
+        if App().download_manager.get():
             self.__progress.show()
-        El().download_manager.connect("download-start",
-                                      self.__on_download)
-        El().download_manager.connect("download-finish",
-                                      self.__on_download)
+        App().download_manager.connect("download-start",
+                                       self.__on_download)
+        App().download_manager.connect("download-finish",
+                                       self.__on_download)
         overlay = builder.get_object("overlay")
         overlay.add_overlay(self.__progress)
         overlay.set_overlay_pass_through(self.__progress, True)
         self.add(builder.get_object("end"))
 
-        # Setup main menu actions
-        adblock_action = Gio.SimpleAction.new_stateful(
-               "adblock",
-               None,
-               GLib.Variant.new_boolean(El().settings.get_value("adblock")))
-        adblock_action.connect("change-state", self.__on_adblock_change_state)
-        self.__window.add_action(adblock_action)
-        popup_action = Gio.SimpleAction.new_stateful(
-               "popupblock",
-               None,
-               GLib.Variant.new_boolean(El().settings.get_value("popupblock")))
-        popup_action.connect("change-state",
-                             self.__on_popup_change_state)
-        self.__window.add_action(popup_action)
-        self.__images_action = Gio.SimpleAction.new_stateful(
-                                                    "imgblock",
-                                                    None,
-                                                    GLib.Variant("b", False))
-        self.__window.add_action(self.__images_action)
-
-        # Setup exceptions actions
-        self.__adblock_exceptions = Gio.SimpleAction.new_stateful(
-                                                   "adblock_exceptions",
-                                                   GLib.VariantType.new("s"),
-                                                   GLib.Variant("s", "none"))
-        self.__adblock_exceptions.connect("activate",
-                                          self.__on_exceptions_activate)
-        self.__window.add_action(self.__adblock_exceptions)
-        self.__popup_exceptions = Gio.SimpleAction.new_stateful(
-                                                   "popup_exceptions",
-                                                   GLib.VariantType.new("s"),
-                                                   GLib.Variant("s", "none"))
-        self.__popup_exceptions.connect("activate",
-                                        self.__on_exceptions_activate)
-        self.__window.add_action(self.__popup_exceptions)
-
     def show_sync_button(self):
         """
             Show sync button allowing user to start sync
@@ -209,6 +175,14 @@ class ToolbarEnd(Gtk.Bin):
             self.__home_button.show()
             self.set_hexpand(True)
 
+    @property
+    def download_button(self):
+        """
+            Get download button
+            @return Gtk.ToogleButton
+        """
+        return self.__download_button
+
 #######################
 # PROTECTED           #
 #######################
@@ -244,7 +218,7 @@ class ToolbarEnd(Gtk.Bin):
         """
         button.hide()
         uri = self.__window.container.current.webview.uri
-        El().websettings.set_accept_tls(uri, False)
+        App().websettings.set_accept_tls(uri, False)
         self.__window.container.close_view(self.__window.container.current)
 
     def _on_fullscreen_button_clicked(self, button):
@@ -260,7 +234,7 @@ class ToolbarEnd(Gtk.Bin):
             @param button as Gtk.Button
         """
         self.__window.close_popovers()
-        self.__window.container.current.webview.load_uri(El().start_page)
+        self.__window.container.current.webview.load_uri(App().start_page)
 
     def _on_menu_button_toggled(self, button):
         """
@@ -268,95 +242,16 @@ class ToolbarEnd(Gtk.Bin):
             @param button as Gtk.ToogleButton
         """
         self.__window.close_popovers()
-        if not button.get_active():
-            return
-        builder = Gtk.Builder()
-        builder.add_from_resource("/org/gnome/Eolie/ActionsMenu.ui")
-        if not self.__download_button.is_visible():
-            builder.get_object("toolbar_items").show()
-
         uri = self.__window.container.current.webview.uri
-        if not uri:
+        if not button.get_active() or not uri:
             return
-        parsed = urlparse(uri)
-        # Adblock exceptions
-        page_ex = El().adblock_exceptions.find(parsed.netloc +
-                                               parsed.path)
-        site_ex = El().adblock_exceptions.find(parsed.netloc)
-        if not page_ex and not site_ex:
-            self.__adblock_exceptions.change_state(GLib.Variant("s", "none"))
-        elif site_ex:
-            self.__adblock_exceptions.change_state(GLib.Variant("s", "site"))
-        else:
-            self.__adblock_exceptions.change_state(GLib.Variant("s", "page"))
-        # Popup exceptions
-        page_ex = El().popup_exceptions.find(parsed.netloc +
-                                             parsed.path)
-        site_ex = El().popup_exceptions.find(parsed.netloc)
-        if not page_ex and not site_ex:
-            self.__popup_exceptions.change_state(GLib.Variant("s", "none"))
-        elif site_ex:
-            self.__popup_exceptions.change_state(GLib.Variant("s", "site"))
-        else:
-            self.__popup_exceptions.change_state(GLib.Variant("s", "page"))
-        # Image action
-        block_images = El().image_exceptions.find(parsed.netloc)
-        self.__images_action.change_state(GLib.Variant("b", block_images))
-
-        popover = Gtk.PopoverMenu.new()
-        fullscreen_button = builder.get_object("fullscreen_button")
-        if self.__window.is_fullscreen:
-            fullscreen_button.set_active(True)
-            fullscreen_button.set_tooltip_text(_("Leave fullscreen"))
-        else:
-            fullscreen_button.set_tooltip_text(_("Enter fullscreen"))
-        builder.connect_signals(self)
-        widget = builder.get_object("widget")
-        webview = self.__window.container.current.webview
-
-        current = El().websettings.get_zoom(webview.uri)
-        if current is None:
-            current = 100
-        builder.get_object("default_zoom_button").set_label(
-                                                        "{} %".format(current))
-        popover.add(widget)
-        exceptions = builder.get_object("exceptions")
-        from eolie.menu_languages import LanguagesMenu
-        from eolie.menu_scripts import ScriptsMenu
-        languages = LanguagesMenu(uri)
-        languages.show()
-        scripts = ScriptsMenu(parsed.netloc)
-        scripts.show()
-        popover.add(exceptions)
-        popover.add(languages)
-        popover.add(scripts)
-        popover.child_set_property(exceptions, "submenu", "exceptions")
-        popover.child_set_property(scripts, "submenu", "scripts")
-        popover.child_set_property(languages, "submenu", "languages")
-        # Merge appmenu, we assume we only have one level (section -> items)
-        if not El().prefers_app_menu():
-            separator = Gtk.Separator.new(Gtk.Orientation.HORIZONTAL)
-            separator.show()
-            widget.add(separator)
-            menu = El().get_app_menu()
-            for i in range(0, menu.get_n_items()):
-                section = menu.get_item_link(i, "section")
-                for y in range(0, section.get_n_items()):
-                    label = section.get_item_attribute_value(y, "label")
-                    action = section.get_item_attribute_value(y, "action")
-                    item = Gtk.ModelButton.new()
-                    item.set_property("text", label.get_string())
-                    item.set_action_name(action.get_string())
-                    item.show()
-                    widget.add(item)
+        from eolie.menu_toolbar import ToolbarMenu
+        popover = ToolbarMenu(uri, self.__window, self)
         popover.set_relative_to(button)
         popover.set_modal(False)
         self.__window.register(popover)
         popover.connect("closed", self.__on_popover_closed, button)
         popover.popup()
-        self.__image_change_state_id = self.__images_action.connect(
-                                                 "change-state",
-                                                 self.__on_image_change_state)
 
     def _on_save_button_clicked(self, button):
         """
@@ -375,47 +270,6 @@ class ToolbarEnd(Gtk.Bin):
         action = self.__window.lookup_action("shortcut")
         action.activate(GLib.Variant("s", "print"))
 
-    def _on_zoom_button_clicked(self, button):
-        """
-            Zoom current page
-            @param button as Gtk.Button
-        """
-        webview = self.__window.container.current.webview
-        current = webview.zoom_in()
-        button.set_label("{} %".format(current))
-
-    def _on_unzoom_button_clicked(self, button):
-        """
-            Unzoom current page
-            @param button as Gtk.Button
-        """
-        webview = self.__window.container.current.webview
-        current = webview.zoom_out()
-        button.set_label("{} %".format(current))
-
-    def _on_fullscreen_button_toggled(self, button):
-        """
-            Restore default zoom level
-            @param button as Gtk.ToggleButton
-        """
-        button.get_ancestor(Gtk.Popover).hide()
-        if button.get_active():
-            if not self.__window.is_fullscreen:
-                self.__window.fullscreen()
-        else:
-            if self.__window.is_fullscreen:
-                self.__window.unfullscreen()
-
-    def _on_default_zoom_button_clicked(self, button):
-        """
-            Restore default zoom level
-            @param button as Gtk.Button
-        """
-        webview = self.__window.container.current.webview
-        El().websettings.set_zoom(100, webview.uri)
-        webview.update_zoom_level()
-        button.set_label("100 %")
-
 #######################
 # PRIVATE             #
 #######################
@@ -438,7 +292,7 @@ class ToolbarEnd(Gtk.Bin):
         if nb_downloads:
             value = fraction / nb_downloads
             self.__progress.set_fraction(value)
-            El().update_unity_badge(value)
+            App().update_unity_badge(value)
         return True
 
     def __on_video_menu_popover_closed(self, popover, model):
@@ -458,50 +312,30 @@ class ToolbarEnd(Gtk.Bin):
         """
         if response_id == Gtk.ResponseType.ACCEPT:
             self.__window.container.current.webview.save_to_file(
-                                    dialog.get_file(),
-                                    WebKit2.SaveMode.MHTML,
-                                    None,
-                                    None)
+                dialog.get_file(),
+                WebKit2.SaveMode.MHTML,
+                None,
+                None)
 
-    def __on_exceptions_activate(self, action, param):
-        """
-            Update exception for current page/site
-            @param action as Gio.SimpleAction
-            @param param as GLib.Variant
-        """
-        uri = self.__window.container.current.webview.uri
-        if not uri:
-            return
-        if action == self.__adblock_exceptions:
-            database = El().adblock_exceptions
-        else:
-            database = El().popup_exceptions
-        action.set_state(param)
-        parsed = urlparse(uri)
-        page_ex = database.find(parsed.netloc + parsed.path)
-        site_ex = database.find(parsed.netloc)
-        # Clean previous exceptions
-        if param.get_string() in ["site", "none"]:
-            if page_ex:
-                database.remove_exception(parsed.netloc + parsed.path)
-        if param.get_string() in ["page", "none"]:
-            if site_ex:
-                database.remove_exception(parsed.netloc)
-        # Add new exceptions
-        if param.get_string() == "site":
-            database.add_exception(parsed.netloc)
-        elif param.get_string() == "page":
-            database.add_exception(parsed.netloc + parsed.path)
-        self.__window.container.current.webview.reload()
-
-    def __on_adblock_change_state(self, action, param):
+    def __on_action_change_state(self, action, param, option):
         """
             Set adblock state
             @param action as Gio.SimpleAction
             @param param as GLib.Variant
+            @param option as str
         """
         action.set_state(param)
-        El().settings.set_value("adblock", param)
+        App().settings.set_value(option, param)
+        self.__window.container.current.webview.reload()
+
+    def __on_trust_change_state(self, action, param):
+        """
+            Set trust state
+            @param action as Gio.SimpleAction
+            @param param as GLib.Variant
+        """
+        action.set_state(param)
+        App().settings.set_value("trust_websites", param)
         self.__window.container.current.webview.reload()
 
     def __on_popup_change_state(self, action, param):
@@ -511,7 +345,7 @@ class ToolbarEnd(Gtk.Bin):
             @param param as GLib.Variant
         """
         action.set_state(param)
-        El().settings.set_value("popupblock", param)
+        App().settings.set_value("popupblock", param)
 
     def __on_image_change_state(self, action, param):
         """
@@ -524,18 +358,9 @@ class ToolbarEnd(Gtk.Bin):
         if parsed.scheme in ["http", "https"]:
             action.set_state(param)
             if param.get_boolean():
-                El().image_exceptions.add_exception(parsed.netloc)
+                App().image_exceptions.add_exception(parsed.netloc)
             else:
-                El().image_exceptions.remove_exception(parsed.netloc)
-
-    def __on_js_change_state(self, action, param):
-        """
-            Update javascript block state
-            @param action as Gio.SimpleAction
-            @param param as GLib.Variant
-        """
-        action.set_state(param)
-        El().settings.set_value("jsblock", param)
+                App().image_exceptions.remove_exception(parsed.netloc)
 
     def __on_download(self, download_manager, name=""):
         """
@@ -551,7 +376,7 @@ class ToolbarEnd(Gtk.Bin):
                                                      download_manager)
         elif self.__timeout_id is not None:
             self.__progress.set_fraction(1.0)
-            El().update_unity_badge(1.0)
+            App().update_unity_badge(1.0)
             GLib.timeout_add(1000, self.__hide_progress)
             GLib.source_remove(self.__timeout_id)
             self.__timeout_id = None
@@ -579,8 +404,8 @@ class ToolbarEnd(Gtk.Bin):
             @param count as int
         """
         try:
-            El().sync_worker.new_session()
-            El().sync_worker.login(attributes, password)
+            App().sync_worker.new_session()
+            App().sync_worker.login(attributes, password)
         except Exception as e:
-            print("ToolbarEnd::__on_get_sync()", e)
+            Logger.error("ToolbarEnd::__on_get_sync(): %s", e)
             self.__sync_button.show()
