@@ -113,7 +113,6 @@ class WebViewSignals(WebViewMenuSignals, WebViewJsSignals,
         self.connect("leave-fullscreen", self.__on_leave_fullscreen)
         self.connect("insecure-content-detected",
                      self.__on_insecure_content_detected)
-        WebViewJsSignals._on_map(self, webview)
         WebViewDBusSignals._on_map(self, webview)
         WebViewLoadSignals._on_map(self, webview)
 
@@ -129,7 +128,6 @@ class WebViewSignals(WebViewMenuSignals, WebViewJsSignals,
         self.disconnect_by_func(self.__on_enter_fullscreen)
         self.disconnect_by_func(self.__on_leave_fullscreen)
         self.disconnect_by_func(self.__on_insecure_content_detected)
-        WebViewJsSignals._on_unmap(self, webview)
         WebViewDBusSignals._on_unmap(self, webview)
         WebViewLoadSignals._on_unmap(self, webview)
 
@@ -200,7 +198,7 @@ class WebViewSignals(WebViewMenuSignals, WebViewJsSignals,
             @param title as str
         """
         parsed = urlparse(webview.uri)
-        if self._error or\
+        if self.error or\
                 webview.ephemeral or\
                 parsed.scheme not in ["http", "https"]:
             return
